==> dif-database-repository-2.2.0-4-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/AuditLogDetail.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.List;
import pt.digitalis.dif.model.utils.AbstractBeanAttributes;

/**
 * AuditLogDetail
 * Generated on ORM Generator
 * DIF build process for the Model layer
 *
 */
@SuppressWarnings("serial")
public class AuditLogDetail extends AbstractBeanAttributes implements java.io.Serializable {

    /** AuditLogDetail attributes enumeration */
    public static class Fields {
        /** id column */
        public static final String ID = "id";
        /** columnName column */
        public static final String COLUMNNAME = "columnName";
        /** previousValue column */
        public static final String PREVIOUSVALUE = "previousValue";
        /** newValue column */
        public static final String NEWVALUE = "newValue";

	    /**
          * List of existing fields
	     *
	     * @return list of field names
	     */
        public static List<String> values() {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("columnName");
            list.add("previousValue");
            list.add("newValue");

            return list;
        }
    }

    /** AuditLogDetail FK class */
    public static class FK {
        /** auditLog relation */
        public static final String AUDITLOG = "auditLog";
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    protected Object getAttributeNoGraphNavigation(String attributeName) {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("auditLog".equalsIgnoreCase(attributeName))
            return auditLog;
        if ("columnName".equalsIgnoreCase(attributeName))
            return columnName;
        if ("previousValue".equalsIgnoreCase(attributeName))
            return previousValue;
        if ("newValue".equalsIgnoreCase(attributeName))
            return newValue;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    @SuppressWarnings("all")
    public void setAttribute(String attributeName, Object attributeValue) {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long)attributeValue;
        if ("auditLog".equalsIgnoreCase(attributeName))
            auditLog = (AuditLog)attributeValue;
        if ("columnName".equalsIgnoreCase(attributeName))
            columnName = (String)attributeValue;
        if ("previousValue".equalsIgnoreCase(attributeName))
            previousValue = (String)attributeValue;
        if ("newValue".equalsIgnoreCase(attributeName))
            newValue = (String)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** auditLog private attribute */
    private AuditLog auditLog;

    /** columnName private attribute */
    private String columnName;

    /** previousValue private attribute */
    private String previousValue;

    /** newValue private attribute */
    private String newValue;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public AuditLogDetail() {
    }

	/** 
	 * minimal constructor
	 *
     * @param auditLog
     * @param columnName
    }
	 */
    public AuditLogDetail(AuditLog auditLog, String columnName) {
        this.auditLog = auditLog;
        this.columnName = columnName;
    }

    /**
     * full constructor
	 *
     * @param auditLog
     * @param columnName
     * @param previousValue
     * @param newValue
     */
    public AuditLogDetail(AuditLog auditLog, String columnName, String previousValue, String newValue) {
        this.auditLog = auditLog;
        this.columnName = columnName;
        this.previousValue = previousValue;
        this.newValue = newValue;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id
     *
     * @return AuditLogDetail modified instance
     */
    public AuditLogDetail setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * auditLog getter method
     *
     * @return auditLog method
     */
    public AuditLog getAuditLog() {
        return this.auditLog;
    }
    
    /**       
     * auditLog setter method
     *
     * @param auditLog
     *
     * @return AuditLogDetail modified instance
     */
    public AuditLogDetail setAuditLog(AuditLog auditLog) {
        this.auditLog = auditLog;
        
        return this;
    }
    /**       
     * columnName getter method
     *
     * @return columnName method
     */
    public String getColumnName() {
        return this.columnName;
    }
    
    /**       
     * columnName setter method
     *
     * @param columnName
     *
     * @return AuditLogDetail modified instance
     */
    public AuditLogDetail setColumnName(String columnName) {
        this.columnName = columnName;
        
        return this;
    }
    /**       
     * previousValue getter method
     *
     * @return previousValue method
     */
    public String getPreviousValue() {
        return this.previousValue;
    }
    
    /**       
     * previousValue setter method
     *
     * @param previousValue
     *
     * @return AuditLogDetail modified instance
     */
    public AuditLogDetail setPreviousValue(String previousValue) {
        this.previousValue = previousValue;
        
        return this;
    }
    /**       
     * newValue getter method
     *
     * @return newValue method
     */
    public String getNewValue() {
        return this.newValue;
    }
    
    /**       
     * newValue setter method
     *
     * @param newValue
     *
     * @return AuditLogDetail modified instance
     */
    public AuditLogDetail setNewValue(String newValue) {
        this.newValue = newValue;
        
        return this;
    }

    /**
     * Creates a String representation of the AuditLogDetail object
     *
     * @return the compiled String
     */
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("columnName").append("='").append(getColumnName()).append("' ");			
        buffer.append("previousValue").append("='").append(getPreviousValue()).append("' ");			
        buffer.append("newValue").append("='").append(getNewValue()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the AuditLogDetail object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(AuditLogDetail other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("columnName".equalsIgnoreCase(attributeName))
        	this.columnName = attributeValue;

        if ("previousValue".equalsIgnoreCase(attributeName))
        	this.previousValue = attributeValue;

        if ("newValue".equalsIgnoreCase(attributeName))
        	this.newValue = attributeValue;

    }


}

==> dif-database-repository-2.3.0-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/AuditLogDetail.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.List;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;

/**
 * AuditLogDetail
 * Generated on ORM Generator
 * DIF build process for the Model layer
 *
 */
@SuppressWarnings("serial")
public class AuditLogDetail extends AbstractBeanRelationsAttributes implements java.io.Serializable {

    /** AuditLogDetail attributes enumeration */
    public static class Fields {
        /** id column */
        public static final String ID = "id";
        /** columnName column */
        public static final String COLUMNNAME = "columnName";
        /** previousValue column */
        public static final String PREVIOUSVALUE = "previousValue";
        /** newValue column */
        public static final String NEWVALUE = "newValue";

	    /**
          * List of existing fields
	     *
	     * @return list of field names
	     */
        public static List<String> values() {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("columnName");
            list.add("previousValue");
            list.add("newValue");

            return list;
        }
    }

	/**
 	 * The Class Relations.
 	 */
	 public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations {

        /**
         * Instantiates a new relations.
         *
         * @param currentPath
         *            the current path
         */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * auditLog relation.
         *
         * @return the auditLog bean relations attributes.
         */
        public AuditLog.Relations auditLog()
        {
			AuditLog c = new AuditLog();
            return c.new Relations(this.buildPath("auditLog"));
        }
        
		/**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
		/**
         * the COLUMNNAME path.
         *
         * @return the path
         */
        public String COLUMNNAME()
        {
            return buildPath(Fields.COLUMNNAME);
        }
		/**
         * the PREVIOUSVALUE path.
         *
         * @return the path
         */
        public String PREVIOUSVALUE()
        {
            return buildPath(Fields.PREVIOUSVALUE);
        }
		/**
         * the NEWVALUE path.
         *
         * @return the path
         */
        public String NEWVALUE()
        {
            return buildPath(Fields.NEWVALUE);
        }
    }
	
	/** The dummy obj. */
    private static AuditLogDetail dummyObj = new AuditLogDetail();

	/**
     * Get AuditLogDetail Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    protected Object getAttributeNoGraphNavigation(String attributeName) {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("auditLog".equalsIgnoreCase(attributeName))
            return auditLog;
        if ("columnName".equalsIgnoreCase(attributeName))
            return columnName;
        if ("previousValue".equalsIgnoreCase(attributeName))
            return previousValue;
        if ("newValue".equalsIgnoreCase(attributeName))
            return newValue;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    @SuppressWarnings("all")
    public void setAttribute(String attributeName, Object attributeValue) {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long)attributeValue;
        if ("auditLog".equalsIgnoreCase(attributeName))
            auditLog = (AuditLog)attributeValue;
        if ("columnName".equalsIgnoreCase(attributeName))
            columnName = (String)attributeValue;
        if ("previousValue".equalsIgnoreCase(attributeName))
            previousValue = (String)attributeValue;
        if ("newValue".equalsIgnoreCase(attributeName))
            newValue = (String)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** auditLog private attribute */
    private AuditLog auditLog;

    /** columnName private attribute */
    private String columnName;

    /** previousValue private attribute */
    private String previousValue;

    /** newValue private attribute */
    private String newValue;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public AuditLogDetail() {
    }

	/** 
	 * minimal constructor
	 *
     * @param auditLog
     * @param columnName
    }
	 */
    public AuditLogDetail(AuditLog auditLog, String columnName) {
        this.auditLog = auditLog;
        this.columnName = columnName;
    }

    /**
     * full constructor
	 *
     * @param auditLog
     * @param columnName
     * @param previousValue
     * @param newValue
     */
    public AuditLogDetail(AuditLog auditLog, String columnName, String previousValue, String newValue) {
        this.auditLog = auditLog;
        this.columnName = columnName;
        this.previousValue = previousValue;
        this.newValue = newValue;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id
     *
     * @return AuditLogDetail modified instance
     */
    public AuditLogDetail setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * auditLog getter method
     *
     * @return auditLog method
     */
    public AuditLog getAuditLog() {
        return this.auditLog;
    }
    
    /**       
     * auditLog setter method
     *
     * @param auditLog
     *
     * @return AuditLogDetail modified instance
     */
    public AuditLogDetail setAuditLog(AuditLog auditLog) {
        this.auditLog = auditLog;
        
        return this;
    }
    /**       
     * columnName getter method
     *
     * @return columnName method
     */
    public String getColumnName() {
        return this.columnName;
    }
    
    /**       
     * columnName setter method
     *
     * @param columnName
     *
     * @return AuditLogDetail modified instance
     */
    public AuditLogDetail setColumnName(String columnName) {
        this.columnName = columnName;
        
        return this;
    }
    /**       
     * previousValue getter method
     *
     * @return previousValue method
     */
    public String getPreviousValue() {
        return this.previousValue;
    }
    
    /**       
     * previousValue setter method
     *
     * @param previousValue
     *
     * @return AuditLogDetail modified instance
     */
    public AuditLogDetail setPreviousValue(String previousValue) {
        this.previousValue = previousValue;
        
        return this;
    }
    /**       
     * newValue getter method
     *
     * @return newValue method
     */
    public String getNewValue() {
        return this.newValue;
    }
    
    /**       
     * newValue setter method
     *
     * @param newValue
     *
     * @return AuditLogDetail modified instance
     */
    public AuditLogDetail setNewValue(String newValue) {
        this.newValue = newValue;
        
        return this;
    }

    /**
     * Creates a String representation of the AuditLogDetail object
     *
     * @return the compiled String
     */
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("columnName").append("='").append(getColumnName()).append("' ");			
        buffer.append("previousValue").append("='").append(getPreviousValue()).append("' ");			
        buffer.append("newValue").append("='").append(getNewValue()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the AuditLogDetail object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(AuditLogDetail other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("columnName".equalsIgnoreCase(attributeName))
        	this.columnName = attributeValue;

        if ("previousValue".equalsIgnoreCase(attributeName))
        	this.previousValue = attributeValue;

        if ("newValue".equalsIgnoreCase(attributeName))
        	this.newValue = attributeValue;

    }


}
